searchData={"items":[{"type":"module","title":"StatsdMetric","doc":"A fast StatsD / DogStatsD metric encoder and single-pass parser.\n\n`StatsdMetric` supports all standard StatsD metric types:\n\n* Counter\n* Gauge\n* Histogram\n* Timer\n* Set\n* Meter\n\nIt also supports DogStatsD sample rates and tags.","ref":"StatsdMetric.html"},{"type":"module","title":"Encoding Example - StatsdMetric","doc":"iex> metric = %StatsdMetric{key: \"name.spaced\", value: 1.0, type: :counter}\n    iex> StatsdMetric.encode(metric)\n    [\"name.spaced\", 58, \"1.0\", 124, \"c\"]\n\n    iex> metric = %StatsdMetric{key: \"name.spaced\", value: 1.0, type: :counter}\n    iex> StatsdMetric.encode_to_string(metric)\n    \"name.spaced:1.0|c\"\n\nDirectly encoding stat parameters is also supported:\n\n    iex> StatsdMetric.encode_parts(\"name.spaced\", 1.0, :counter)\n    [\"name.spaced\", 58, \"1.0\", 124, \"c\"]\n\n    iex> StatsdMetric.encode_parts_to_string(\"name.spaced\", 1.0, :counter)\n    \"name.spaced:1.0|c\"","ref":"StatsdMetric.html#module-encoding-example"},{"type":"module","title":"Parsing Example - StatsdMetric","doc":"iex> StatsdMetric.decode!(\"name.spaced:1.0|c|@0.1|#foo:bar\")\n    [%StatsdMetric{\n      key: \"name.spaced\",\n      value: 1.0,\n      type: :counter,\n      sample_rate: 0.1,\n      tags: %{\"foo\" => \"bar\"}\n    }]\n\nMultiple metrics separated by a newline are also supported:\n\n    iex> StatsdMetric.decode!(\"first.metric:1.0|c|@0.1|#foo:bar\\nsecond.metric:15.0|g|#foo:bar\")\n    [\n      %StatsdMetric{\n        key: \"first.metric\",\n        value: 1.0,\n        type: :counter,\n        sample_rate: 0.1,\n        tags: %{\"foo\" => \"bar\"}\n      },\n      %StatsdMetric{\n        key: \"second.metric\",\n        value: 15.0,\n        type: :gauge,\n        tags: %{\"foo\" => \"bar\"}\n      }\n    ]","ref":"StatsdMetric.html#module-parsing-example"},{"type":"function","title":"StatsdMetric.decode/1","doc":"Parses StatsD metrics into a list of `%StatsdMetric{}`.\n\n    iex> StatsdMetric.decode(\"name.spaced:1.0|c|@0.1|#foo:bar\")\n    {:ok, [%StatsdMetric{\n      key: \"name.spaced\",\n      value: 1.0,\n      type: :counter,\n      sample_rate: 0.1,\n      tags: %{\"foo\" => \"bar\"}\n    }]}","ref":"StatsdMetric.html#decode/1"},{"type":"function","title":"StatsdMetric.decode!/1","doc":"Parses StatsD metrics into a list of `%StatsdMetric{}`.\n\n    iex> StatsdMetric.decode!(\"name.spaced:1.0|c|@0.1|#foo:bar\")\n    [%StatsdMetric{\n      key: \"name.spaced\",\n      value: 1.0,\n      type: :counter,\n      sample_rate: 0.1,\n      tags: %{\"foo\" => \"bar\"}\n    }]\n\nIf any of the metrics are invalid, it raises one of:\n\n- `StatsdMetric.EmptyError`\n- `StatsdMetric.NoKeyError`\n- `StatsdMetric.NoValueError`\n- `StatsdMetric.NoTypeError`","ref":"StatsdMetric.html#decode!/1"},{"type":"function","title":"StatsdMetric.encode/1","doc":"Encodes a `%StatsdMetric{}` into a StatsD metric IO list.\n\n    iex> StatsdMetric.encode(%StatsdMetric{key: \"name.spaced\", value: 1.0, type: :counter})\n    [\"name.spaced\", 58, \"1.0\", 124, \"c\"]","ref":"StatsdMetric.html#encode/1"},{"type":"function","title":"StatsdMetric.encode_parts/4","doc":"Encodes stat parameters into a StatsD metric IO list.\n\n    iex> StatsdMetric.encode_parts(\"name.spaced\", 1.0, :counter)\n    [\"name.spaced\", 58, \"1.0\", 124, \"c\"]","ref":"StatsdMetric.html#encode_parts/4"},{"type":"function","title":"StatsdMetric.encode_parts_to_string/4","doc":"Encodes stat parameters into a StatsD metric string.\n\n    iex> StatsdMetric.encode_parts_to_string(\"name.spaced\", 1.0, :counter)\n    \"name.spaced:1.0|c\"","ref":"StatsdMetric.html#encode_parts_to_string/4"},{"type":"function","title":"StatsdMetric.encode_to_string/1","doc":"Encodes a `%StatsdMetric{}` into a StatsD metric string.\n\n    iex> StatsdMetric.encode_to_string(%StatsdMetric{key: \"name.spaced\", value: 1.0, type: :counter})\n    \"name.spaced:1.0|c\"","ref":"StatsdMetric.html#encode_to_string/1"},{"type":"type","title":"StatsdMetric.t/0","doc":"","ref":"StatsdMetric.html#t:t/0"},{"type":"exception","title":"StatsdMetric.BadValueError","doc":"An exception raised when the stat passed to the decoder has a value that can't\nbe parsed into a float.","ref":"StatsdMetric.BadValueError.html"},{"type":"exception","title":"StatsdMetric.EmptyError","doc":"An exception raised when the stat passed to the decoder is empty.","ref":"StatsdMetric.EmptyError.html"},{"type":"exception","title":"StatsdMetric.NoKeyError","doc":"An exception raised when the stat passed to the decoder has no key.","ref":"StatsdMetric.NoKeyError.html"},{"type":"exception","title":"StatsdMetric.NoTypeError","doc":"An exception raised when the stat passed to the decoder has no type.","ref":"StatsdMetric.NoTypeError.html"},{"type":"exception","title":"StatsdMetric.NoValueError","doc":"An exception raised when the stat passed to the decoder has no value.","ref":"StatsdMetric.NoValueError.html"}],"content_type":"text/markdown"}